@@ -9,7 +9,7 @@ with describe('be_above'):
         expect(5).to(be_above(4))
 
     with it('should fail if number is not above expected'):
-        with failure('Expected 1 to be above 4'):
+        with failure('expected: 1 to be above 4'):
             expect(1).to(be_above(4))
 
     with context('#negated'):
@@ -17,5 +17,5 @@ with describe('be_above'):
             expect(1).not_to(be_above(4))
 
         with it('should fail if number is above expected'):
-            with failure('Expected 5 not to be above 4'):
+            with failure('expected: 5 not to be above 4'):
                 expect(5).not_to(be_above(4))
