@@ -9,7 +9,7 @@ with describe('be_below'):
         expect(1).to(be_below(4))
 
     with it('should fail if number is not below expected'):
-        with failure('Expected 4 to be below 1'):
+        with failure('expected: 4 to be below 1'):
             expect(4).to(be_below(1))
 
     with context('#negated'):
@@ -17,5 +17,5 @@ with describe('be_below'):
             expect(4).not_to(be_below(1))
 
         with it('should fail if number is below expected'):
-            with failure('Expected 1 not to be below 4'):
+            with failure('expected: 1 not to be below 4'):
                 expect(1).not_to(be_below(4))
