@@ -9,7 +9,7 @@ with describe('be_true'):
         expect(True).to(be_true)
 
     with it('should fail if object is false'):
-        with failure('Expected False to be true'):
+        with failure('expected: False to be true'):
             expect(False).to(be_true)
 
     with context('#negated'):
@@ -17,5 +17,5 @@ with describe('be_true'):
             expect(False).not_to(be_true)
 
         with it('should fail if object is true'):
-            with failure('Expected True not to be true'):
+            with failure('expected: True not to be true'):
                 expect(True).not_to(be_true)
