@@ -12,7 +12,7 @@ with describe('be_within'):
         expect(5.5).to(be_within(4, 7))
 
     with it('should fail if integer is not within expected range'):
-        with failure('Expected 1 to be within 4 and 7'):
+        with failure('expected: 1 to be within 4 and 7'):
             expect(1).to(be_within(4, 7))
 
     with context('#negated'):
@@ -20,5 +20,5 @@ with describe('be_within'):
             expect(1).not_to(be_within(4, 7))
 
         with it('should fail if integer is within expected range'):
-            with failure('Expected 5 not to be within 4 and 7'):
+            with failure('expected: 5 not to be within 4 and 7'):
                 expect(5).not_to(be_within(4, 7))
